.ColorScheme-Text {
    color: {{ colors["Text"] }};
}

.ColorScheme-Background {
    color: {{ colors["Background"] }};
}

.ColorScheme-Highlight {
    color: {{ colors["Highlight"] }};
}

.ColorScheme-ViewText {
    color: {{ colors["ViewText"] }};
}

.ColorScheme-ViewBackground {
    color: {{ colors["ViewBackground"] }};
}

.ColorScheme-ViewHover {
    color: {{ colors["ViewHover"] }};
}

.ColorScheme-ViewFocus {
    color: {{ colors["ViewFocus"] }};
}

.ColorScheme-ButtonText {
    color: {{ colors["ButtonText"] }};
}

.ColorScheme-ButtonBackground {
    color: {{ colors["ButtonBackground"] }};
}

.ColorScheme-ButtonHover {
    color: {{ colors["ButtonHover"] }};
}

.ColorScheme-ButtonFocus {
    color: {{ colors["ButtonFocus"] }};
}
