# -*- coding: utf-8 -*-
"""
This package holds actual logic for data manipulation and transformation

Modules:
    builder: functions to assemble an XML document for the output SVG image
    wrappers: class representations of an SVG image and color scheme

Packages:
    parsers: holds modules that parse source svg image and color theme file
"""
